@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2011 by Barry A. Warsaw
+# Copyright (C) 2004-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.password
 #
@@ -31,7 +31,7 @@ __all__ = [
     ]
 
 
-__version__ = '1.1'
+__version__ = '1.1.1'
 
 
 from ._hash import make_secret
@@ -39,3 +39,7 @@ from ._generate import generate
 from ._registry import BadPasswordSchemeError, lookup, register
 from ._utils import BadPasswordFormatError
 from ._verify import verify
+
+# Register the built-in schemes by import, but don't expose this in the API.
+# Users should import specific schemes explicitly.
+from . import schemes as _schemes
